..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.
    Copyright (C) 2022 RERO.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. automodule:: invenio_oauth2server.ext
   :members:

Decorators
----------

.. automodule:: invenio_oauth2server.decorators
   :members:

Models
------

.. automodule:: invenio_oauth2server.models
   :members:

Provider
--------

.. automodule:: invenio_oauth2server.provider
   :members:

Validators
----------

.. automodule:: invenio_oauth2server.validators
   :members:

..
   Proxies is not working because of current_app throws an exception:
   'Working outside of application context'.
.. Proxies
.. -------

.. .. automodule:: invenio_oauth2server.proxies
..    :members:


Errors
------

.. automodule:: invenio_oauth2server.errors
   :members:
